diff src/menu_processor.asm @ 275:653a3ab08062

rename into hwOS
author heinrichsweikamp
date Thu, 07 May 2015 13:11:14 +0200
parents e1e5876bd777
children 5ad479f2a868
line wrap: on
line diff
--- a/src/menu_processor.asm	Tue May 05 14:58:16 2015 +0200
+++ b/src/menu_processor.asm	Thu May 07 13:11:14 2015 +0200
@@ -2,16 +2,16 @@
 ;
 ;   File menu_processor.asm
 ;
 ;   Routines to handle all OSTC3 graphic/text menus.
 ;
 ;   Copyright (c) 2011, JD Gascuel, HeinrichsWeikamp, all right reserved.
 ;=============================================================================
 ; HISTORY
-;   2012-11-02 : [jDG] Cleanup for OSTC3: removed icons. Added scrolling.
+;   2012-11-02 : [jDG] Cleanup for hwOS: removed icons. Added scrolling.
 ;                      But need a font with lower/upper alpha chars...
 
 #include "convert.inc"
-#include "ostc3.inc"
+#include "hwos.inc"
 #include "strings.inc"
 #include "tft.inc"
 #include "varargs.inc"
@@ -259,7 +259,7 @@
 menu_vertical_2:
         rcall   menu_draw_lines			; Always re-draw whole menu
 
-		movlw	CCP1CON_VALUE			; See ostc3.inc
+		movlw	CCP1CON_VALUE			; See hwos.inc
         btfss   divemode                ; Not in divemode
 		movwf	CCP1CON                 ; Power-on backlight
@@ -2,16 +2,16 @@
 ;   File menu_processor.asm
 ;
-;   Routines to handle all OSTC3 graphic/text menus.
+;   Routines to handle all hwOS graphic/text menus.
 ;
 ;   Copyright (c) 2011, JD Gascuel, HeinrichsWeikamp, all right reserved.